function success=skewt(pz,tz,qz)
%
% Calculates and displays a sounding on a skew-T chart. Pseudo-adiabats
% from entropy definition by George Bryan (Mon. Wea. Rev., 2008).
%
% pz = pressure (hPa), tz = temperature (C)
% qz=relative humidity (%) if lowest level value is in range 0.5-100; 
%   otherwise qz is assumed to be specific humidity (g/g).
%
%-------------------------------------------------------------------------
%
%   First check to see if qz is relative or specific humidity
%
qsize=max(size(qz));
imin=100;
for i=1:qsize
    if ~isnan(qz(i)) && qz(i) ~= 0
        imin=min(i,imin);
    end
end  
if imin == 100
    disp(' ')
    disp('No humidity data, quitting')
    return
end    
if qz(imin) > 0.5
    ez=6.112.*exp(17.67.*tz./(243.5+tz));
    qz=0.01*qz.*0.622.*ez./(pz-ez);
end
%
chi=log(pz.*qz./(6.112.*(0.622+qz)));
tdz=243.5.*chi./(17.67-chi);    % Dewpoint temperature
%
p=1050:-25:100;      % Range of pressure in plot
pplot=transpose(p);
t0=-48:2:50;         % Range of temperature at 1000 hPa in plot
[ps1,ps2]=size(p);
ps=max(ps1,ps2);
[ts1,ts2]=size(t0);
ts=max(ts1,ts2);
Lvcp=2.555e3./1005;   % 0.001*Bryan optimum value of Lv, divided by cp
Rdcp=287/1005;
tem=zeros(ts,ps);
thet=zeros(ts,ps);
thetaea=zeros(ts,ps);
q=zeros(ts,ps);
for i=1:ts
   for j=1:ps
      tem(i,j)=t0(i)+30.*log(0.001.*p(j));  %  Skewed temperature
      thet(i,j)=(273.15+tem(i,j)).*(1000./p(j)).^Rdcp;
      es=6.112.*exp(17.67.*tem(i,j)./(243.5+tem(i,j)));
      q(i,j)=622.*es./(p(j)-es);
      thetaea(i,j)=thet(i,j).*exp(Lvcp*q(i,j)./(tem(i,j)+273.15));
   end
end
t0=transpose(t0);
temp=transpose(tem);
theta=transpose(thet);
thetae=transpose(thetaea);
qs=transpose(sqrt(q));
[~]=contour(t0,pplot,temp,16,'k');
hold on
set(gca,'ytick',1000:100:100)
set(gca,'ylim',[100 1000])
set(gca,'yscale','log','ydir','reverse')
set(gca,'fontweight','bold')
set(gca,'ytick',100:100:1000)
set(gca,'ygrid','on')
hold on
[~]=contour(t0,pplot,theta,24,'b');
[~]=contour(t0,pplot,qs,24,'g');
[~]=contour(t0,pplot,thetae,24,'r');
%tsound=30.+43.5.*log(0.001.*p);
%tsoundm=tsound-30.*log(0.001.*p);
tzm=tz-30.*log(0.001.*pz);
tdzm=tdz-30.*log(0.001.*pz);
h=plot(tzm,pz,'r',tdzm,pz,'g');
set(h,'linewidth',2)
hold off
xlabel('Temperature (C)','fontweight','bold')
ylabel('Pressure (mb)','fontweight','bold')
success='yes';
